<?php

//print_r($_SERVER);die();

$sitepad['db_name'] = 'fqnewsco_sp155';
$sitepad['db_user'] = 'fqnewsco_sp155';
$sitepad['db_pass'] = '.Spp]89Oj8';
$sitepad['db_host'] = 'localhost';
$sitepad['db_table_prefix'] = 'spoy_';
$sitepad['charset'] = 'utf8mb4';
$sitepad['collate'] = 'utf8mb4_unicode_ci';
$sitepad['serving_url'] = 'radio.fq-news.com/sp';// URL without protocol but with directory as well
$sitepad['url'] = 'https://radio.fq-news.com/sp';
$sitepad['relativeurl'] = '/sp';
$sitepad['.sitepad'] = '/home/fqnewsco';
$sitepad['sitepad_plugin_path'] = '/var/softaculous/sitepad';
$sitepad['editor_path'] = '/home/fqnewsco/sitepad-editor';
$sitepad['path'] = dirname(__FILE__);
$sitepad['AUTH_KEY'] = 'gx5r5juvb68uugvtefb48xmmfnhrraozgfhurcfqbmgxcnn1cq7jn0vbzfwqmzzc';
$sitepad['SECURE_AUTH_KEY'] = 'xsbq6gqbwdtdhv0jiw3vvdqqruaf3rrwfhsuuy8zajp3232yymxlsu649kjtzxnk';
$sitepad['LOGGED_IN_KEY'] = 'c27k6hdo6b4wowov2ojmdbb4lcathfobazq8dbkdol4kuaow2gftdwvjpwjqljdx';
$sitepad['NONCE_KEY'] = 'mksenmcubrnxjsc9u8ovzw4yloii2bhvmxc7s4hlkhxlbphxxcx2yzf0m8x5s1g5';
$sitepad['AUTH_SALT'] = '7xpssqlvp7cngkelgogoij4xrwp7v2trudvbn0ucptx1clqiu3epkf898lmgcbuh';
$sitepad['SECURE_AUTH_SALT'] = 'z0zaqmegux98j7xp1i777nreudljhggrhegj5w8r8xeipvc9revzalspyznv5bt0';
$sitepad['LOGGED_IN_SALT'] = 'o5ca4a95gvtye3akhvif9wvamtlnmdk4uw6a8kvcrjwunjuzkcopeccb7lcvdeh9';
$sitepad['NONCE_SALT'] = 'fsiyfcq9mxjysvv70e2uzviadf7rh5ape2ruflnmqrbgy8ejmftnjfkkay5qtaep';

if(!include_once($sitepad['editor_path'].'/site-inc/bootstrap.php')){
	die('Could not include the bootstrap.php. One of the reasons could be open_basedir restriction !');
}

